@@ -139,7 +139,7 @@ class User:
         self.write_speed_limit_per_connection = \
             write_speed_limit_per_connection
 
-    def get_permissions(self, path):
+    async def get_permissions(self, path):
         """
         Return nearest parent permission for `path`.
 
@@ -536,7 +536,9 @@ class PathPermissions:
         @functools.wraps(f)
         async def wrapper(cls, connection, rest, *args):
             real_path, virtual_path = cls.get_paths(connection, rest)
-            current_permission = connection.user.get_permissions(virtual_path)
+            current_permission = await connection.user.get_permissions(
+                virtual_path,
+            )
             for permission in self.permissions:
                 if not getattr(current_permission, permission):
                     connection.response("550", "permission denied")
@@ -1242,6 +1244,9 @@ class Server:
             del connection.data_connection
             async with stream:
                 async for path in connection.path_io.list(real_path):
+                    if not (await connection.path_io.exists(path)):
+                        logger.warning("path %r does not exists", path)
+                        continue
                     s = await self.build_list_string(connection, path)
                     b = (s + END_OF_LINE).encode(encoding=self.encoding)
                     await stream.write(b)
